Index: src/gpu/GrPipelineBuilder.h |
diff --git a/src/gpu/GrPipelineBuilder.h b/src/gpu/GrPipelineBuilder.h |
index fa085f0b993153bec51753f3edab933a3c4b6155..0e6f7175c780a305a690d2f289a632884179c722 100644 |
--- a/src/gpu/GrPipelineBuilder.h |
+++ b/src/gpu/GrPipelineBuilder.h |
@@ -177,10 +177,10 @@ public: |
} |
/** |
* Checks whether the xp will need a copy of the destination to correctly blend. |
*/ |
- bool willXPNeedDstCopy(const GrDrawTargetCaps& caps, const GrProcOptInfo& colorPOI, |
- const GrProcOptInfo& coveragePOI) const; |
+ bool willXPNeedDstTexture(const GrDrawTargetCaps& caps, const GrProcOptInfo& colorPOI, |
+ const GrProcOptInfo& coveragePOI) const; |
/// @} |
@@ -177,10 +177,10 @@ public: |
} |
/** |
- * Checks whether the xp will need a copy of the destination to correctly blend. |
+ * Checks whether the xp will need destination in a texture to correctly blend. |
*/ |